# Owl2diagram

## How to run locally
```
python 
```

## How to use

   `python -m owl2diagram "https://raw.githubusercontent.com/jatoledo/owl2diagram/main/images/SCTO.owl" output.md`


## Example

## Version

```
0.1.0
```

## Authors

- Jhon Toledo.
